.. qeschema documentation master file, created by
   sphinx-quickstart on Fri Oct 25 15:14:13 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

===============================================
Quantum Espresso XML Schema tools documentation
===============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   usage
   api
   usage
